<?php
/*
 * Dokuwiki's Main Configuration File - Local Settings
 * Auto-generated by config plugin
 * Run for user: xmlrpcuser
 * Date: Wed, 19 Dec 2012 21:45:24 +0100
 */

$conf['title'] = 'test xmlrpc';
$conf['license'] = 'cc-by-sa';
$conf['useheading'] = '1';
$conf['useacl'] = 1;
$conf['superuser'] = '@admin';
$conf['remote'] = 1;
$conf['remoteuser'] = 'xmlrpcuser,writeruser,norightsuser';
//for DW up to 2012-01-25b
$conf['xmlrpc'] = 1;
$conf['xmlrpcuser'] = 'xmlrpcuser,writeruser,norightsuser';

// end auto-generated content
