package dw.xmlrpc.exception;

public class DokuMisConfiguredWikiException extends DokuException {

	private static final long serialVersionUID = 7988621871633643736L;

	public DokuMisConfiguredWikiException(String message, Throwable cause) {
		super(message, cause);
	}
}
