# users.auth.php
# <?php exit()?>
# Don't modify the lines above
#
# Userfile
#
# Format:
#
# login:passwordhash:Real Name:email:groups,comma,seperated


xmlrpcuser:$1$0TQWcl7p$fsl5QHQMcJ1hN4pKpQkrB0:xmlrpcuser:xml@rpc:admin,user
writeruser:$1$U7Eovyk4$JO.B.1x9SWUFhklKh7516.:writeruser:wri@ter:user
norightsuser:$1$2fTAmWKY$zuoiU7ibDsUpbXFEP7l130:norightsuser:no@rights:untouchables
