package dw.xmlrpc.exception;

public class DokuPageDoesNotExistException extends DokuException {
	private static final long serialVersionUID = 8579585910287045131L;

	public DokuPageDoesNotExistException(Throwable cause) {
		super(cause);
	}

}