# acl.auth.php
# <?php exit()?>
# Don't modify the lines above
#
# Access Control Lists
#
# Auto-generated by install script
# Date: Sun, 16 Dec 2012 10:55:52 +0000
*	@ALL	0
*	norightsuser	0
*	@user	8
